@@ -36,4 +36,4 @@ fi
 ( cd usr/bin ; rm -rf slogin )
 ( cd usr/bin ; ln -sf ./ssh slogin )
 ( cd usr/man/man1 ; rm -rf slogin.1.gz )
-( cd usr/man/man1 ; ln -sf ssh.1.gz slogin.1.gz )
+( cd usr/man/man1 ; ln -sf ./ssh.1.gz slogin.1.gz )
